"use strict";
/*
 * Copyright 2018-2020 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const application_1 = require("@elyra/application");
const apputils_1 = require("@jupyterlab/apputils");
const React = __importStar(require("react"));
class PipelineService {
    static getRuntimes() {
        return __awaiter(this, void 0, void 0, function* () {
            const runtimes = yield application_1.FrontendServices.getMetadata('runtimes');
            if (Object.keys(runtimes).length === 0) {
                return application_1.FrontendServices.noMetadataError('runtimes');
            }
            return runtimes;
        });
    }
    static getRuntimeImages() {
        return __awaiter(this, void 0, void 0, function* () {
            const runtimeImages = yield application_1.FrontendServices.getMetadata('runtime-images');
            if (Object.keys(runtimeImages).length === 0) {
                return application_1.FrontendServices.noMetadataError('runtime-images');
            }
            const images = {};
            for (const image in runtimeImages) {
                const imageName = runtimeImages[image]['metadata']['image_name'];
                images[imageName] = runtimeImages[image]['display_name'];
            }
            return images;
        });
    }
    static submitPipeline(pipeline, runtime_config) {
        return __awaiter(this, void 0, void 0, function* () {
            console.log('Pipeline definition:');
            console.log(pipeline);
            const response = yield application_1.RequestHandler.makePostRequest('elyra/pipeline/schedule', JSON.stringify(pipeline), true);
            const dialogTitle = 'Job submission to ' + runtime_config + ' succeeded';
            const dialogBody = (React.createElement("p", null,
                "Check the status of your pipeline at",
                ' ',
                React.createElement("a", { href: response['run_url'], target: "_blank", rel: "noopener noreferrer" }, "Run Details."),
                React.createElement("br", null),
                "The results and outputs are in the ",
                response['object_storage_path'],
                ' ',
                "working directory in",
                ' ',
                React.createElement("a", { href: response['object_storage_url'], target: "_blank", rel: "noopener noreferrer" }, "object storage"),
                "."));
            return apputils_1.showDialog({
                title: dialogTitle,
                body: dialogBody,
                buttons: [apputils_1.Dialog.okButton()]
            });
        });
    }
    static exportPipeline(pipeline, pipeline_export_format, pipeline_export_path, overwrite) {
        return __awaiter(this, void 0, void 0, function* () {
            console.log('Pipeline definition:');
            console.log(pipeline);
            console.log('Exporting pipeline to [' + pipeline_export_format + '] format');
            console.log('Overwriting existing file: ' + overwrite);
            const body = {
                pipeline: pipeline,
                export_format: pipeline_export_format,
                export_path: pipeline_export_path,
                overwrite: overwrite
            };
            yield application_1.RequestHandler.makePostRequest('elyra/pipeline/export', JSON.stringify(body), true);
            return apputils_1.showDialog({
                title: 'Pipeline export succeeded',
                body: React.createElement("p", null),
                buttons: [apputils_1.Dialog.okButton()]
            });
        });
    }
}
exports.PipelineService = PipelineService;
//# sourceMappingURL=PipelineService.js.map